Author: Marina Guvakova

# PARAMETERS

NB. When scrolling parameter window with mouse wheel, it can happen that the cursor stops at a slider widget. In this case, continuing to roll the wheel will not scroll the window but will move the slider and change its value which could be unintentional.

## Models: model learning control tools

- 'Model with fixed k (no)' is a slider for setting the fixed number of bins (k) in a histogram (range 10-115). The only model is learned based on a histogram with the chosen k.

- 'Model with varying k and the lowest BIC (yes) ' is a slider for setting varying binning parameter k. The default is a fixed k= 25 with a half-length of vector k =3 (checkbox for varying k is ticked). This setting allows learning of multiple models with a vector of k {10, 15, 20, 25, 30, 35, 40}. Software selects the model with the lowest BIC.

- 'Threshold for fusing too close Gaussians' is a slider for tuning a merge of Gaussian distributions that are too close to each other (range 0-1; default 0.5)

- 'Threshold for vanishing Gaussians' is a slider for tuning a disappearance of Gaussian distributions with too low number of values; (range 0-10; default 1.0)

## Evaluating parameter stability: controlling resampling

- 'Resample': checkbox to say if resampling should be done or not (default: no). Note that the resampling is done without replacement.
- 'Fraction of sample': a slider for setting a real number between 0 and 1 indicating the fraction which will be present in new samples (default: 0.9).
- 'Number of resamples': a slider for setting an integer number between 1 and 100 (default: 5). The larger this value, the more runtime is needed for resampling but the more reliable the statistics are.
- 'What to resample?': checkboxes to choose between 'ref', 'test' or both (default: 'ref').
- 'use seed': checkbox to say if a seed (i.e. reproducible resampling) should be used (default: no). This option activation can be helpful only for debugging or bug reporting.
- 'Seed value': a slider for setting an integer value used as a seed (default: 7).

## Plots: plots and heatmaps visualization control tools

- Histogram colors

  - Edge

  - Panels

- Gaussian colors

  - Total of Gaussian densities

  - Reference class '0'

  - Low class '-1'

  - Lowest class '-N'

  - Up class '+1'

  - Highest class '+N'

- 'Area under Gaussians (0=transparent, 1=opaque)' slider; (range 0-1; defaults 0.5)

- 'Line width for Gaussians' defaults' slider (range 0-10; default 2.0)

## Heatmaps: checkbox selection tool (the default is all 3 heatmaps)

- probabilistic

- cutoff

- s.cutoff

## Buttons

- 'Defaults' resets all the parameters to default settings

- 'Learn model' fits probabilistic model on the test data which are presented as a histogram. Because information about the number of bins and their boundaries is not inherent to the data, but will influence a model, it is advisable to apply varying binning parameters to the test data. Each newly built model is visualized by clicking on "Learn model" button.

- 'Draw plots' allows to re-draw customized histograms and plots

- 'Draw heatmaps' constructs classification heatmaps other than by default